@@ -528,6 +528,6 @@ class SearchSubscriber implements EventSubscriberInterface
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/LeadBundle/EventListener/SearchSubscriber.php", "/var/www/mautic-ktn/app/bundles/LeadBundle/EventListener/SearchSubscriber.php");
+        return new Source("", "@bundles/LeadBundle/EventListener/SearchSubscriber.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/EventListener/SearchSubscriber.php");
     }
 }
