@@ -546,6 +546,6 @@ q
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/aurora/assets/open-sans/OpenSans-Bold.WOFF", "/var/www/mautic-ktn/themes/aurora/assets/open-sans/OpenSans-Bold.WOFF");
+        return new Source("", "@themes/aurora/assets/open-sans/OpenSans-Bold.WOFF", "/var/www/html/mauticGIT-Test/themes/aurora/assets/open-sans/OpenSans-Bold.WOFF");
     }
 }
