@@ -843,6 +843,6 @@ class AssetController extends FormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/AssetBundle/Controller/AssetController.php", "/var/www/mautic-ktn/app/bundles/AssetBundle/Controller/AssetController.php");
+        return new Source("", "@bundles/AssetBundle/Controller/AssetController.php", "/var/www/html/mauticGIT-Test/app/bundles/AssetBundle/Controller/AssetController.php");
     }
 }
